==> gpointing-device-settings_1.3.1.orig.tar.gz: gpointing-device-settings-1.3.1/modules/common/gpds-mouse-definitions.h <==
/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 *  Copyright (C) 2009 Hiroyuki Ikezoe  <poincare@ikezoe.net>
 *
 *  This library is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef __GPDS_MOUSE_GCONF_H__
#define __GPDS_MOUSE_GCONF_H__

#define GPDS_MOUSE_GCONF_DIR                   "/desktop/gnome/peripherals"
#define GPDS_MOUSE_MIDDLE_BUTTON_EMULATION_KEY "middle_button_emulation"
#define GPDS_MOUSE_MIDDLE_BUTTON_TIMEOUT_KEY   "middle_button_timeoue"
#define GPDS_MOUSE_WHEEL_EMULATION_KEY         "wheel_emulation"
#define GPDS_MOUSE_WHEEL_EMULATION_INERTIA_KEY "wheel_emulation_inetia"
#define GPDS_MOUSE_WHEEL_EMULATION_X_AXIS_KEY  "wheel_emulation_x_axis"
#define GPDS_MOUSE_WHEEL_EMULATION_Y_AXIS_KEY  "wheel_emulation_y_axis"
#define GPDS_MOUSE_WHEEL_EMULATION_TIMEOUT_KEY "wheel_emulation_timeout"
#define GPDS_MOUSE_WHEEL_EMULATION_BUTTON_KEY  "wheel_emulation_button"
#define GPDS_MOUSE_DRAG_LOCK_BUTTONS_KEY       "drag_lock_buttons"

#endif /* __GPDS_MOUSE_GCONF_H__ */
/*
vi:ts=4:nowrap:ai:expandtab:sw=4
*/

==> gpointing-device-settings_1.5.1.orig.tar.gz: gpointing-device-settings-1.5.1/modules/common/gpds-mouse-definitions.h <==
/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 *  Copyright (C) 2009 Hiroyuki Ikezoe  <poincare@ikezoe.net>
 *
 *  This library is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef __GPDS_MOUSE_GCONF_H__
#define __GPDS_MOUSE_GCONF_H__

#define GPDS_MOUSE_GCONF_DIR                   "/desktop/gnome/peripherals"
#define GPDS_MOUSE_MIDDLE_BUTTON_EMULATION_KEY "middle_button_emulation"
#define GPDS_MOUSE_MIDDLE_BUTTON_TIMEOUT_KEY   "middle_button_timeout"
#define GPDS_MOUSE_WHEEL_EMULATION_KEY         "wheel_emulation"
#define GPDS_MOUSE_WHEEL_EMULATION_INERTIA_KEY "wheel_emulation_inertia"
#define GPDS_MOUSE_WHEEL_EMULATION_X_AXIS_KEY  "wheel_emulation_x_axis"
#define GPDS_MOUSE_WHEEL_EMULATION_Y_AXIS_KEY  "wheel_emulation_y_axis"
#define GPDS_MOUSE_WHEEL_EMULATION_TIMEOUT_KEY "wheel_emulation_timeout"
#define GPDS_MOUSE_WHEEL_EMULATION_BUTTON_KEY  "wheel_emulation_button"
#define GPDS_MOUSE_DRAG_LOCK_BUTTONS_KEY       "drag_lock_buttons"

#endif /* __GPDS_MOUSE_GCONF_H__ */
/*
vi:ts=4:nowrap:ai:expandtab:sw=4
*/
